      function onWaveCurve(rho,rhoC,momC,dir,centSide,
     &     onWaveCurveExpan,onWaveCurveCompr)
      implicit none
c
c     Computes a VALUE at state W; 
c         state W lies ON a general wave-curve;
c         the wave-curve is centered at state C.
c     
c
c     onWaveCurveExpan computes the VALUE on an EXPANSION portion of the curve 
c     onWaveCurveCompr computes the VALUE on a COMPRESSION portion of the curve
c
c     C is the state at which the wave-curve is centered.
c     With respect to the wave, 
c     state C could be either Ahead or Behind.
c             rhoC --- density  at state C
c             momC --- momentum at state C 
c
c     W is the state ON the wave-curve at which the VALUE is computed.
c     (W is the side of the wave opposite to C)
c     With respect to the wave, 
c     state W could be either Behind or Ahead.
c             rho --- density at state W
c
c     The state at which the wave-curve is centered is defined
c     by a pair {rhoC,momC}.
c     The wave curve is parametrized with the density, rho. 
c 
c     Whether C is Ahead (Behind) and W is Behind (Ahead)
c     depends on the value of centSide
c             centSide =  -1 state C is Behind, state W is Ahead
c                         +1 state C  is Ahead, state W is Behind
c
c     dir  --- -1 1-wave-curve
c              +1 2-wave-curve
c 
c     Output: onWaveCurve  --- value on the wave-curve
c
c     Auxiliary: comp --- compression rho/rhoC 
c
      
c     Input      
      real*8 rho,rhoC,momC
      integer dir,centSide
      external onWaveCurveExpan,onWaveCurveCompr
      real*8 onWaveCurveExpan,onWaveCurveCompr
c     Output
      real*8 onWaveCurve
c     Auxiliary
      real*8 comp

      comp = rho/rhoC

      if ( (comp-1.d0)*centSide .le. 0.d0) then
         onWaveCurve = onWaveCurveExpan(comp,rhoC,momC,dir)
      else
         onWaveCurve = onWaveCurveCompr(comp,rhoC,momC,dir)
      endif

      end
