      function rho2momCompr(comp,rhoC,momC,dir)
      implicit none
c
c     Computes the momentum at state W;
c         state W lies ON the COMPRESSION portion of a wave-curve;
c         the wave-curve is centered at state C.
c 
c     C is the state at which the wave-curve is centered.
c     (With respect to the wave, 
c     state C could be either Ahead or Behind.)
c
c     W is the state ON the wave-curve.
c     (W is the side of the wave opposite to C)
c     (With respect to the wave, 
c     state W could be either Behind or Ahead.)
c
c     The state at which the wave-curve is centered is defined
c     by a pair {rhoC,momC}.
c     The wave curve is parametrized with compression, comp = rho/rhoC.
c
c------------------------------------------------------------------------
c------------------------------------------------------------------------ 
c 
c     Input: 
c             comp --- compression rho/rhoC, 
c                      where rho --- density at state W
c             rhoC --- density  at state C
c             momC --- momentum at state C
c             dir  --- -1 1-wave-curve
c                      +1 2-wave-curve
c
c 
c     Output: rho2momCompr  --- momentum at state W         
c

      include 'mat_constants.h'

c     Input      
      real*8 comp,rhoC,momC
      integer dir
c     Output
      real*8 rho2momCompr

      rho2momCompr = momC*comp+dir*rhoC*a0*dsqrt(comp)*(comp-1.d0) 

      end
