      function st2W(rho,mom,rhoC,momC,dir)
      implicit none
c
c     Computes the Speed of Discontinuity 
c                        connecting state C and state W;
c         state W lies ON the COMPRESSION portion of a wave-curve;
c         the wave-curve is centered at state C.
c 
c     C is the state at which the wave-curve is centered.
c     (With respect to the wave, 
c     state C could be either Ahead or Behind.)
c
c     W is the state ON the wave-curve.
c     (W is the side of the wave opposite to C)
c     (With respect to the wave, 
c     state W could be either Behind or Ahead.)
c
c     The state at which the wave-curve is centered is defined
c     by a pair {rhoC,momC}.
c     The wave curve is parametrized with compression, comp = rho/rhoC.
c
c     Input:
c               STATE C
c               -----------------------
c            rhoC    density 
c            momC    momentum 
c               STATE W
c               -----------------------
c            rho    density
c            mom    momentum
c
c            dir =+1 for right-facing wave, =-1 for left-facing wave
c     Output:
c            st2W --- wave velocity 
c
      include 'mat_constants.h'  
       
c     Input
      real*8 rho,mom,rhoC,momC
      integer dir
c     Output
      real*8 st2W
c-----

      st2W = momC/rhoC+dir*a0*dsqrt(rho/rhoC)

      end


