      subroutine states(rhoL,momL,rhoM,momM,rhoR,momR,
     &     rho_0,mom_0,w_0,signif_0,wave_type_0)
      implicit none
c
c-----------------------------------------------------------------------
c                              INPUT 
c-----------------------------------------------------------------------
c
c
c       {Left,Middle,Right} STATE VARIABLES:
c       -----------------------------------
c    rho{L,C,R}  density
c    mom{L,C,R}  momentum
c-------------------------------------------------------------------------
c                            OUTPUT 
c-------------------------------------------------------------------------
c
c          STATE VARIABLES
c          ---------------
c    rho_0(1:N_STATES)   density
c    mom_0(1:N_STATES)   momentum
c     1 - Left Init. State;  2 - Middle State; 3 - Right Init. State
c
c         WAVE STRUCTURE 
c         --------------
c    1 - left-facing wave; 2 - right-facing wave
c
c    wave_type_0(1:N_WAVES) -- type of the wave
c     = RFN rarefaction fan
c     = SFR shock front
c
c    signif_0(1:N_WAVES) =1 if the wave is signigicant; =0 otherwise
c       THIS INFORMATION IS GIVEN FOR WAVE TRACKING PURPOSES: 
c       signif_0(i) = 1: i-th wave should be tracked
c       signif_0(i) = 0: i-th wave should not be tracked
c
c    EACH WAVE CAN BE EITHER A RAREFACTION FAN OR A SHARP FRONT.  
c    THE FOLLOWING CONVENTION IS USED: 
c    A SHARP FRONT IS DESCRIBED AS A FAN WHOSE EDGES COINCIDE.
c
c    w_0(1:N_EDGES)    velocities of the fan-edges:
c        w_0(1) = velocity of the outer  edge of the left-f fan
c        w_0(2) = velocity of the innner edge of the left-f fan
c        w_0(3) = velocity of the inner  edge of the right-f fan
c        w_0(4) = velocity of the outer  edge of the right-f fan
c
c
      include 'wave_constants.h'

c     Input:
      real*8 rhoL,momL,rhoM,momM,rhoR,momR
c     Output:
      real*8  rho_0(N_STATES),mom_0(N_STATES),w_0(N_EDGES)
      integer signif_0(N_WAVES),wave_type_0(N_WAVES)


c     left state and wave:
      call statesO(rhoL,momL, rhoM,momM, DIR_L,
     &     rho_0,mom_0,w_0,signif_0,wave_type_0)

c     right state and wave:
      call statesO(rhoR,momR, rhoM,momM, DIR_R,
     &     rho_0,mom_0,w_0,signif_0,wave_type_0)

c     middle state:
      call st2st(rhoM,momM,rho_0(2),mom_0(2))

      end
